@@ -1,9 +1,11 @@
-#@author: kushal
+# @author: kushal
 
-#Chatzigeorgiou Group
-#Sars International Centre for Marine Molecular Biology
+# Chatzigeorgiou Group
+# Sars International Centre for Marine Molecular Biology
 
-#GNU GENERAL PUBLIC LICENSE Version 3, 29 June 2007
+# GNU GENERAL PUBLIC LICENSE Version 3, 29 June 2007
+
+__version__ = '0.2.3'
 
 
 import os
@@ -11,7 +13,6 @@ from webbrowser import open_new_tab as open_new_web_browser_tab
 import configparser
 from datetime import datetime
 from time import time
-from .. import docs
 from .configuration import get_sys_config, console_history_path
 from functools import partial
 from PyQt5.QtWidgets import QApplication
@@ -34,10 +35,7 @@ def get_proj_config(proj_path: str = None) -> configparser.RawConfigParser:
     return proj_cfg
 
 
-# docs_dir = os.path.dirname(docs.__file__)
-# docs_dir = docs_dir + '/user_guides'
-
-docs_dir = 'http://mesmerizelab.org/'
+docs_dir = f'https://docs.mesmerizelab.org/en/v{__version__}/'
 
 doc_pages = \
     {
